@@ -35,11 +35,11 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.36.0"
+#define LIBFDISK_VERSION   "2.37.1"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   36
-#define LIBFDISK_PATCH_VERSION   0
+#define LIBFDISK_MINOR_VERSION   37
+#define LIBFDISK_PATCH_VERSION   1
 
 /**
  * fdisk_context:
@@ -298,6 +298,7 @@ struct fdisk_parttype *fdisk_label_advparse_parttype(
  * @FDISK_PARTTYPE_PARSE_DEFAULT: recommended flags for new code
  * @FDISK_PARTTYPE_PARSE_NOUNKNOWN: ignore unknown types
  * @FDISK_PARTTYPE_PARSE_SEQNUM: use input as sequntial number of type (e.g. list-types fdisk dialog)
+ * @FDISK_PARTTYPE_PARSE_NAME: parse type human readable name
  */
 enum fdisk_parttype_parser_flags {
 	FDISK_PARTTYPE_PARSE_DATA       = (1 << 1),
@@ -307,10 +308,12 @@ enum fdisk_parttype_parser_flags {
 	FDISK_PARTTYPE_PARSE_DEPRECATED = (1 << 5),
 	FDISK_PARTTYPE_PARSE_NOUNKNOWN  = (1 << 6),
 	FDISK_PARTTYPE_PARSE_SEQNUM     = (1 << 7),
+	FDISK_PARTTYPE_PARSE_NAME	= (1 << 8),
 
 	FDISK_PARTTYPE_PARSE_DEFAULT = (FDISK_PARTTYPE_PARSE_DATA | \
 				        FDISK_PARTTYPE_PARSE_SHORTCUT | \
 				        FDISK_PARTTYPE_PARSE_ALIAS | \
+					FDISK_PARTTYPE_PARSE_NAME | \
 					FDISK_PARTTYPE_PARSE_SEQNUM )
 };
 
@@ -872,9 +875,12 @@ size_t fdisk_ask_menu_get_nitems(struct fdisk_ask *ask);
 int fdisk_ask_print_get_errno(struct fdisk_ask *ask);
 const char *fdisk_ask_print_get_mesg(struct fdisk_ask *ask);
 
-int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...);
-int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...);
+int fdisk_info(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warn(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
+int fdisk_warnx(struct fdisk_context *cxt, const char *fmt, ...)
+			__attribute__ ((__format__ (__printf__, 2, 3)));
 
 /* utils.h */
 extern char *fdisk_partname(const char *dev, size_t partno);
